@@ -3,8 +3,11 @@ from __future__ import annotations
 import logging
 import os
 
+import importlib_metadata
 from fastapi import FastAPI
+from fastapi.middleware.cors import CORSMiddleware
 from fastapi.staticfiles import StaticFiles
+from prometheus_client import make_asgi_app
 from pydantic import BaseSettings
 
 import murfey.server
@@ -30,12 +33,28 @@ class Settings(BaseSettings):
 settings = Settings()
 
 app = FastAPI(title="Murfey server", debug=True, openapi_tags=tags_metadata)
+
+metrics_app = make_asgi_app()
+app.mount("/metrics", metrics_app)
+
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=["*"],
+    allow_credentials=True,
+    allow_methods=["*"],
+    allow_headers=["*"],
+)
+
 app.mount("/static", StaticFiles(directory=template_files / "static"), name="static")
 app.mount("/images", StaticFiles(directory=template_files / "images"), name="images")
 
 app.include_router(murfey.server.bootstrap.bootstrap)
 app.include_router(murfey.server.bootstrap.cygwin)
 app.include_router(murfey.server.bootstrap.pypi)
+app.include_router(murfey.server.bootstrap.plugins)
 app.include_router(murfey.server.websocket.ws)
 
 app.include_router(router)
+
+for r in importlib_metadata.entry_points(group="murfey.routers"):
+    app.include_router(r.load())
